Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nodejs/node.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMichaƫl Zasso <targos@protonmail.com>2020-12-06 12:07:47 +0300
committerMichael Dawson <mdawson@devrus.com>2020-12-11 04:21:26 +0300
commit7e5bf48998f7bd0a512d7e5340e1614dfdc8cf97 (patch)
tree10fc19b922171a567ca5ff54ef031130effd3988
parent72b07e4fcf8843ec0c7a82ba2ec3250429671ef5 (diff)
build,lib,test: change whitelist to allowlist
PR-URL: https://github.com/nodejs/node/pull/36406 Reviewed-By: Anna Henningsen <anna@addaleax.net> Reviewed-By: Colin Ihrig <cjihrig@gmail.com> Reviewed-By: Rich Trott <rtrott@gmail.com> Reviewed-By: Luigi Pinca <luigipinca@gmail.com> Reviewed-By: Michael Dawson <midawson@redhat.com>
-rwxr-xr-xconfigure.py2
-rw-r--r--lib/internal/bootstrap/loaders.js8
-rw-r--r--test/common/README.md8
-rw-r--r--test/common/index.js4
-rw-r--r--test/parallel/test-process-binding-internalbinding-allowlist.js (renamed from test/parallel/test-process-binding-internalbinding-whitelist.js)2
5 files changed, 12 insertions, 12 deletions
diff --git a/configure.py b/configure.py
index 50994c8c277..0f65f185aff 100755
--- a/configure.py
+++ b/configure.py
@@ -948,7 +948,7 @@ def get_gas_version(cc):
# Note: Apple clang self-reports as clang 4.2.0 and gcc 4.2.1. It passes
# the version check more by accident than anything else but a more rigorous
-# check involves checking the build number against a whitelist. I'm not
+# check involves checking the build number against an allowlist. I'm not
# quite prepared to go that far yet.
def check_compiler(o):
if sys.platform == 'win32':
diff --git a/test/common/README.md b/test/common/README.md
index 5ce7473cb51..9bbc107dd85 100644
--- a/test/common/README.md
+++ b/test/common/README.md
@@ -40,12 +40,12 @@ The `benchmark` module is used by tests to run benchmarks.
The `common` module is used by tests for consistency across repeated
tasks.
-### `allowGlobals(...whitelist)`
+### `allowGlobals(...allowlist)`
-* `whitelist` [&lt;Array>][] Array of Globals
+* `allowlist` [&lt;Array>][] Array of Globals
* return [&lt;Array>][]
-Takes `whitelist` and concats that with predefined `knownGlobals`.
+Takes `allowlist` and concats that with predefined `knownGlobals`.
### `canCreateSymLink()`
@@ -601,7 +601,7 @@ If set, crypto tests are skipped.
### `NODE_TEST_KNOWN_GLOBALS`
A comma-separated list of variables names that are appended to the global
-variable whitelist. Alternatively, if `NODE_TEST_KNOWN_GLOBALS` is set to `'0'`,
+variable allowlist. Alternatively, if `NODE_TEST_KNOWN_GLOBALS` is set to `'0'`,
global leak detection is disabled.
## Fixtures Module
diff --git a/test/common/index.js b/test/common/index.js
index 0952f5de52f..39caa1b6b68 100644
--- a/test/common/index.js
+++ b/test/common/index.js
@@ -276,8 +276,8 @@ if (global.gc) {
knownGlobals.push(global.gc);
}
-function allowGlobals(...whitelist) {
- knownGlobals = knownGlobals.concat(whitelist);
+function allowGlobals(...allowlist) {
+ knownGlobals = knownGlobals.concat(allowlist);
}
if (process.env.NODE_TEST_KNOWN_GLOBALS !== '0') {
diff --git a/test/parallel/test-process-binding-internalbinding-whitelist.js b/test/parallel/test-process-binding-internalbinding-allowlist.js
index 9768ef66741..10667b843cd 100644
--- a/test/parallel/test-process-binding-internalbinding-whitelist.js
+++ b/test/parallel/test-process-binding-internalbinding-allowlist.js
@@ -4,7 +4,7 @@
const common = require('../common');
const assert = require('assert');
-// Assert that whitelisted internalBinding modules are accessible via
+// Assert that allowed internalBinding modules are accessible via
// process.binding().
assert(process.binding('async_wrap'));
assert(process.binding('buffer'));
diff --git a/lib/internal/bootstrap/loaders.js b/lib/internal/bootstrap/loaders.js
index d939c2911d0..cae3200e677 100644
--- a/lib/internal/bootstrap/loaders.js
+++ b/lib/internal/bootstrap/loaders.js
@@ -69,11 +69,11 @@ ObjectDefineProperty(process, 'moduleLoadList', {
});
// internalBindingWhitelist contains the name of internalBinding modules
// that are whitelisted for access via process.binding()... This is used
// to provide a transition path for modules that are being moved over to
// internalBinding.
-const internalBindingWhitelist = new SafeSet([
+const internalBindingAllowlist = new SafeSet([
'async_wrap',
'buffer',
'cares_wrap',
@@ -113,7 +113,7 @@ const internalBindingWhitelist = new SafeSet([
module = String(module);
// Deprecated specific process.binding() modules, but not all, allow
// selective fallback to internalBinding for the deprecated ones.
- if (internalBindingWhitelist.has(module)) {
+ if (internalBindingAllowlist.has(module)) {
return internalBinding(module);
}
// eslint-disable-next-line no-restricted-syntax
@@ -69,11 +69,11 @@ ObjectDefineProperty(process, 'moduleLoadList', {
});
-// internalBindingWhitelist contains the name of internalBinding modules
-// that are whitelisted for access via process.binding()... This is used
+// internalBindingAllowlist contains the name of internalBinding modules
+// that are allowed for access via process.binding()... This is used
// to provide a transition path for modules that are being moved over to
// internalBinding.